| Title: | Tukey g-&-h Distribution |
|---|---|
| Description: | Density, cumulative density, quantile and simulation of the 4-parameter Tukey g-and-h (1977) distributions. The quantile-based transformation (Hoaglin 1985 <doi:10.1002/9781118150702.ch11>) and its reverse transformation. |
| Authors: | Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>) |
| Maintainer: | Tingting Zhan <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2.0 |
| Built: | 2026-07-20 15:46:26 UTC |
| Source: | https://github.com/tingtingzhan/tukeygh77 |
Density, cumulative density, quantile and simulation of the 4-parameter Tukey g-and-h (1977) distributions. The quantile-based transformation (Hoaglin 1985 doi:10.1002/9781118150702.ch11) and its reverse transformation.
Maintainer: Tingting Zhan [email protected] (ORCID)
Authors:
Tingting Zhan [email protected] (ORCID)
Tukey, J.W. (1977): Modern Techniques in Data Analysis. In: NSF-sponsored Regional Research Conference at Southeastern Massachusetts University, North Dartmouth, MA.
Hoaglin, D.C. (1985): Summarizing shape numerically: The -and- distributions.
Exploring data tables, trends, and shapes, pp. 461–513.
John Wiley & Sons, Ltd, New York.
-&- DistributionDensity, distribution, quantile and simulation
for Tukey -&- distribution with
location parameter ,
scale parameter ,
skewness and
elongation .
dGH(x, A = 0, B = 1, g = 0, h = 0, log = FALSE, ...) rGH(n, A = 0, B = 1, g = 0, h = 0) qGH(p, A = 0, B = 1, g = 0, h = 0, lower.tail = TRUE, log.p = FALSE) pGH(q, A = 0, B = 1, g = 0, h = 0, lower.tail = TRUE, log.p = FALSE, ...)dGH(x, A = 0, B = 1, g = 0, h = 0, log = FALSE, ...) rGH(n, A = 0, B = 1, g = 0, h = 0) qGH(p, A = 0, B = 1, g = 0, h = 0, lower.tail = TRUE, log.p = FALSE) pGH(q, A = 0, B = 1, g = 0, h = 0, lower.tail = TRUE, log.p = FALSE, ...)
x |
double vector, quantiles |
A |
double scalar, location parameter |
B |
double scalar, scale parameter |
g |
double scalar, skewness parameter |
h |
double scalar, elongation parameter |
log, log.p
|
logical scalar, if |
... |
additional parameters of function |
n |
integer scalar, number of observations |
p |
|
lower.tail |
logical scalar, if |
q |
Density function dGH() returns double vector.
Distribution function pGH() returns double vector.
Quantile function qGH() returns double vector.
Random generator function rGH() returns double vector.
dGH(x, g = .3, h = .1) |> curve(from = -2.5, to = 3.5) pGH(x, g = .3, h = .1) |> curve(from = -2.5, to = 3.5) qGH(x, g = .3, h = .1) |> curve(from = 0, to = 1)dGH(x, g = .3, h = .1) |> curve(from = -2.5, to = 3.5) pGH(x, g = .3, h = .1) |> curve(from = -2.5, to = 3.5) qGH(x, g = .3, h = .1) |> curve(from = 0, to = 1)