Package 'TukeyGH77'

Title: Tukey g-&-h Distribution
Description: Density, cumulative density, quantile and simulation of the 4-parameter Tukey g-and-h (1977) distributions. The quantile-based transformation (Hoaglin 1985 <doi:10.1002/9781118150702.ch11>) and its reverse transformation, as well as the letter-value based estimates (Hoaglin 1985).
Authors: Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>)
Maintainer: Tingting Zhan <[email protected]>
License: GPL-2
Version: 0.2.0
Built: 2026-05-16 09:26:20 UTC
Source: https://github.com/tingtingzhan/tukeygh77

Help Index


TukeyGH77: Tukey g-&-h Distribution

Description

Density, cumulative density, quantile and simulation of the 4-parameter Tukey g-and-h (1977) distributions. The quantile-based transformation (Hoaglin 1985 doi:10.1002/9781118150702.ch11) and its reverse transformation, as well as the letter-value based estimates (Hoaglin 1985).

Note

Help files of individual functions are intentionally suppressed in the pdf manual. Users are encouraged to get started with

vignette('intro', package = 'TukeyGH77')

Author(s)

Maintainer: Tingting Zhan [email protected] (ORCID)

Authors:


Derivative of z2gh() against z, on the log-scale

Description

Derivative of z2gh() against z, on the log-scale

Usage

d_z2GH(z, g, h)

Arguments

z

double vector, missingness allowed

g, h

double scalars

Note

Nomenclature follows the parameters of ?scales::new_transform